**********************
Full Reference Metrics
**********************

Full reference metrics take two images and compare a modified image to a reference image.

.. toctree::
    :maxdepth: 1

    fr_metrics/psnr
    fr_metrics/rmse
    fr_metrics/uqi
    fr_metrics/ssim
    fr_metrics/msssim
    fr_metrics/fsim
    fr_metrics/vif
    fr_metrics/vsi
    fr_metrics/gsm
    fr_metrics/mad